/*
AndikaNewBasic-webfont-example.css
Andika New Basic v5.500
This file is part of Andika New Basic font family (http://scripts.sil.org/andika)
and is Copyright (c) 2004-2015 SIL International (http://www.sil.org/),
with Reserved Font Names "Andika" and "SIL". This Font Software is licensed
under the SIL Open Font License, Version 1.1. You should have received a copy
of the license along with this Font Software. If this is not the case, go to
(http://scripts.sil.org/OFL) for all the details including a FAQ.
*/

/* use Andika New Basic - Regular in .woff format */
@font-face {
  font-family: AndikaNewBasicW;
  src: url(AndikaNewBasic-R.woff);
}

/* set body to use Andika New Basic in .woff format */
body {
  font-family: AndikaNewBasicW, serif;
    /* fall back to serif so that it's really obvious if the fonts don't load */
}
/* remove bold styling from heading */
h1 {
  font-weight: normal;	
}
